// Copyright 2020 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import UIKit

import ArcGIS

class ViewController: UIViewController {

    @IBOutlet var sceneView: AGSSceneView!

    private func setupScene() {

        let scene = AGSScene(basemapStyle: .arcGISImageryStandard)

        let elevationSurface: AGSSurface = {
            let elevationServiceURL = URL(string: "https://elevation3d.arcgis.com/arcgis/rest/services/WorldElevation3D/Terrain3D/ImageServer")!
            let elevationSource = AGSArcGISTiledElevationSource(url: elevationServiceURL)
            let surface = AGSSurface()
            surface.elevationSources.append(elevationSource)
            surface.elevationExaggeration = 2.5
            return surface
        }()

        scene.baseSurface = elevationSurface

        let initialViewpoint = AGSViewpoint(
            center: AGSPoint(x: -118.805, y: 34.027, spatialReference: .wgs84()),
            scale: 10000,
            camera: AGSCamera(
                location: AGSPoint(x: -118.804, y: 33.909, z: 5330.0, spatialReference: .wgs84()),
                heading: 355.0,
                pitch: 72.0,
                roll: 0.0
            )
        )

        scene.initialViewpoint = initialViewpoint

        sceneView.scene = scene

    }

    override func viewDidLoad() {
        super.viewDidLoad()

        setupScene()

    }

}


